@* Common definitions for MIX assembler and simulator.

The purpose is to simulate TAOCP MIX machine with 64 distinct
values per byte, 5 bytes per machine word and with address space
of 4000 words.

Internally, each byte will be represented by 6 bits, with a value
range of |000| to |077|. Sign is represented by a single bit, |0| for
plus or |1| for minus in the first position of the real word.

A word will then occupy 4 actual 8-bit hardware bytes of the real machine
and leave one bit (the second bit of the real word) over for possible
future use.

@d MEMSIZE 4000
@d BYTESIZE 6
@d BYTESPERWORD 5
@d B1 (1<<BYTESIZE)
@d B2 B1*B1
@d B3 B2*B1
@d B5 B2*B3
@d MINUS ((unsigned)2*B5)
@d PLUS 0
@d SIGN(a) (a&(MINUS))      /* sign of word */
@d MAG(a)  (a&(B5-1))       /* magnitude of word */
@d T 1                      /* True value */
@d F 0                      /* False value */

@ |struct mixop| keeps data for a single MIX instruction. It is used
by assembler (|mixal|) to generate machine code and by terminal
emulator (|mixsim -t|) to disassemble instructions.

@c
struct mix_op {  
     char *name;       /* Option mnemonic name */
     int f;            /* Default field notation */
     int c;            /* Opcode */
     int notation;     /* Field notation: 0 - (n), 1 - (l:r) */
};

@ External data provided by the automatically generated file optab.c
@c 
extern struct mix_op mix_optab[]; /* Array of available MIX instructions */
extern int op_count;              /* Number of entries in |mix_optab| */
extern int dd_cnt[];   /* Number of bytes in instruction. */
extern int dd_ent[];   /* Index to |mix_optab| */

